package com.ruoyi.web.controller.platform;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageInfo;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.BaseParam;
import com.ruoyi.system.domain.ComponentsLibrary;
import com.ruoyi.system.service.ComponentsLibraryService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 组件库Controller
 *
 * @author liming
 * @date 2023-07-12
 */
@RestController
@RequestMapping("/platform/v1/components")
public class ComponentsLibraryController extends BaseController {
    @Autowired
    private ComponentsLibraryService componentsLibraryService;

    /**
     * 查询组件库列表
     */
//    @PreAuthorize("@ss.hasPermi('platform:components:list')")
    @PostMapping("/list")
    public R<PageInfo<ComponentsLibrary>> list(@RequestBody BaseParam param) {
        IPage<ComponentsLibrary> basicLibraryIPage = componentsLibraryService.page(new Page<ComponentsLibrary>().setCurrent(param.getCurrent()).setSize(param.getSize()),
                new LambdaQueryWrapper<ComponentsLibrary>().like(param.getName()!=null,ComponentsLibrary::getName,param.getName())
                        .eq(ComponentsLibrary::getDelFlag,"0"));
        PageInfo<ComponentsLibrary> pageInfo = new PageInfo<>();
        pageInfo.setRecords(basicLibraryIPage.getRecords());
        pageInfo.setSize(param.getSize());
        pageInfo.setCurrent(basicLibraryIPage.getCurrent());
        pageInfo.setTotal(basicLibraryIPage.getTotal());
        return R.ok(pageInfo);
    }


    /**
     * 查询基础库列表
     */
    @ApiOperation("查询组件库管理列表")
//    @PreAuthorize("@ss.hasPermi('platform:base:list')")
    @PostMapping("/allList")
    public R<List<ComponentsLibrary>> getAllList() {
        List<ComponentsLibrary> basicLibraryList = componentsLibraryService.list(new LambdaQueryWrapper<ComponentsLibrary>().eq(ComponentsLibrary::getDelFlag,0));
        return R.ok(basicLibraryList);
    }


    /**
     * 获取组件库详细信息
     */
//    @PreAuthorize("@ss.hasPermi('platform:components:query')")
    @PostMapping(value = "/getInfo")
    public R<ComponentsLibrary> getInfo(@RequestBody BaseParam param) {

        return R.ok(componentsLibraryService.getOne(new LambdaQueryWrapper<ComponentsLibrary>().eq(ComponentsLibrary::getId,param.getId())
                .eq(ComponentsLibrary::getDelFlag,"0"),false));
    }

    /**
     * 新增修改组件库
     */
//    @PreAuthorize("@ss.hasPermi('platform:components:add')")
    @Log(title = "组件库", businessType = BusinessType.INSERT)
    @PostMapping("addOrUpdate")
    public R<Boolean> add(@RequestBody ComponentsLibrary param) {
        if (param.getId() != null) {
            param.setUpdateTime(DateUtils.getNowDate());
        }else {
            param.setCreateTime(DateUtils.getNowDate());
        }
        return R.ok(componentsLibraryService.saveOrUpdate(param));
    }


    /**
     * 删除组件库
     */
//    @PreAuthorize("@ss.hasPermi('platform:components:remove')")
    @Log(title = "组件库", businessType = BusinessType.DELETE)
	@PostMapping("/delete")
    public R remove(@RequestBody BaseParam param) {
        ComponentsLibrary componentsLibrary = new ComponentsLibrary();
        componentsLibrary.setId(param.getId());
        componentsLibrary.setDelFlag("2");
        boolean sta = componentsLibraryService.updateById(componentsLibrary);
        if (!sta){
            return R.fail("删除失败");
        }
        return R.ok();
    }
}
