package com.ruoyi.web.controller.platform;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageInfo;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.BaseParam;
import com.ruoyi.system.domain.TemplateLibrary;
import com.ruoyi.system.service.TemplateLibraryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 红外遥控模板库Controller
 * 
 * @author liming
 * @date 2023-07-12
 */
@RestController
@RequestMapping("/platform/v1/template")
public class TemplateLibraryController extends BaseController {
    @Autowired
    private TemplateLibraryService templateLibraryService;

    /**
     * 查询模板库列表
     */
//    @PreAuthorize("@ss.hasPermi('platform:template:list')")
    @PostMapping("/list")
    public R<IPage<TemplateLibrary>> list(@RequestBody BaseParam param) {
        IPage<TemplateLibrary> templateIPage = templateLibraryService.page(new Page<TemplateLibrary>().setCurrent(param.getCurrent()).setSize(param.getSize()),
                new LambdaQueryWrapper<TemplateLibrary>().like(param.getName()!=null,TemplateLibrary::getName,param.getName())
                        .eq(TemplateLibrary::getDelFlag,0));
        PageInfo<TemplateLibrary> pageInfo = new PageInfo<>();
        pageInfo.setRecords(templateIPage.getRecords());
        pageInfo.setTotal(templateIPage.getTotal());
        return R.ok(templateIPage);
    }


    /**
     * 获取模板库详细信息
     */
//    @PreAuthorize("@ss.hasPermi('platform:template:query')")
    @PostMapping(value = "/getInfo")
    public R<TemplateLibrary> getInfo(@RequestBody BaseParam param) {

        return R.ok(templateLibraryService.getOne(new LambdaQueryWrapper<TemplateLibrary>().eq(TemplateLibrary::getId,param.getId())
                .eq(TemplateLibrary::getDelFlag,"0"),false));
    }

    /**
     * 新增模板库
     */
//    @PreAuthorize("@ss.hasPermi('platform:template:add')")
    @Log(title = "模板库", businessType = BusinessType.INSERT)
    @PostMapping("addOrUpdate")
    public R<Boolean> add(@RequestBody TemplateLibrary param) {
        if (param.getId() != null) {
            param.setUpdateTime(DateUtils.getNowDate());
        }else {
            param.setCreateTime(DateUtils.getNowDate());
        }
        return R.ok(templateLibraryService.saveOrUpdate(param));
    }


    /**
     * 删除模板库
     */
//    @PreAuthorize("@ss.hasPermi('platform:template:remove')")
    @Log(title = "模板库", businessType = BusinessType.DELETE)
	@PostMapping("/delete")
    public R<Object> remove(@RequestBody BaseParam param) {
        TemplateLibrary templateLibrary = new TemplateLibrary();
        templateLibrary.setId(param.getId());
        templateLibrary.setDelFlag("2");
        boolean salt = templateLibraryService.updateById(templateLibrary);
        if (!salt){
            return R.fail("删除失败");
        }
        return R.ok();
    }
}
